# Generated by Django 3.2.7 on 2022-03-22 19:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('advanced_report_builder', '0006_auto_20220310_1147'),
    ]

    operations = [
        migrations.AddField(
            model_name='tablereport',
            name='order_by_ascending',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='tablereport',
            name='order_by_field',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]
